@@ -71,7 +71,7 @@ t_CKBOOL type_engine_scan1_exp_postfix( Chuck_Env * env, a_Exp_Postfix postfix )
 t_CKBOOL type_engine_scan1_exp_dur( Chuck_Env * env, a_Exp_Dur dur );
 t_CKBOOL type_engine_scan1_exp_array( Chuck_Env * env, a_Exp_Array array );
 t_CKBOOL type_engine_scan1_exp_func_call( Chuck_Env * env, a_Exp_Func_Call func_call );
-t_CKBOOL type_engine_scan1_exp_func_call( Chuck_Env * env, a_Exp exp_func, a_Exp args, 
+t_CKBOOL type_engine_scan1_exp_func_call( Chuck_Env * env, a_Exp exp_func, a_Exp args,
                                           t_CKFUNC & ck_func, int linepos );
 t_CKBOOL type_engine_scan1_exp_dot_member( Chuck_Env * env, a_Exp_Dot_Member member );
 t_CKBOOL type_engine_scan1_exp_if( Chuck_Env * env, a_Exp_If exp_if );
@@ -108,7 +108,7 @@ t_CKBOOL type_engine_scan2_exp_postfix( Chuck_Env * env, a_Exp_Postfix postfix )
 t_CKBOOL type_engine_scan2_exp_dur( Chuck_Env * env, a_Exp_Dur dur );
 t_CKBOOL type_engine_scan2_exp_array( Chuck_Env * env, a_Exp_Array array );
 t_CKBOOL type_engine_scan2_exp_func_call( Chuck_Env * env, a_Exp_Func_Call func_call );
-t_CKBOOL type_engine_scan2_exp_func_call( Chuck_Env * env, a_Exp exp_func, a_Exp args, 
+t_CKBOOL type_engine_scan2_exp_func_call( Chuck_Env * env, a_Exp exp_func, a_Exp args,
                                           t_CKFUNC & ck_func, int linepos );
 t_CKBOOL type_engine_scan2_exp_dot_member( Chuck_Env * env, a_Exp_Dot_Member member );
 t_CKBOOL type_engine_scan2_exp_if( Chuck_Env * env, a_Exp_If exp_if );
@@ -152,7 +152,7 @@ t_CKBOOL type_engine_scan0_prog( Chuck_Env * env, a_Program prog,
         case ae_section_stmt:
             // do nothing
             break;
-        
+
         case ae_section_func:
             // do nothing
             break;
@@ -180,7 +180,7 @@ t_CKBOOL type_engine_scan0_prog( Chuck_Env * env, a_Program prog,
             // scan the class definition
             ret = type_engine_scan0_class_def( env, prog->section->class_def );
             break;
-        
+
         default:
             EM_error2( prog->linepos,
                 "internal error: unrecognized program section in type checker pre-scan..." );
@@ -190,7 +190,7 @@ t_CKBOOL type_engine_scan0_prog( Chuck_Env * env, a_Program prog,
 
         prog = prog->next;
     }
-    
+
     // pop indent
     EM_poplog();
 
@@ -296,16 +296,16 @@ t_CKBOOL type_engine_scan0_class_def( Chuck_Env * env, a_Class_Def class_def )
         {
         case ae_section_stmt:
             break;
-        
+
         case ae_section_func:
             break;
-        
+
         case ae_section_class:
             // do the class
             ret = type_engine_scan0_class_def( env, body->section->class_def );
             break;
         }
-        
+
         // move to the next section
         body = body->next;
     }
@@ -395,7 +395,7 @@ t_CKBOOL type_engine_scan1_prog( Chuck_Env * env, a_Program prog,
             // scan the statements
             ret = type_engine_scan1_stmt_list( env, prog->section->stmt_list );
             break;
-        
+
         case ae_section_func:
             // if only classes, then skip
             if( how_much == te_do_classes_only ) break;
@@ -409,7 +409,7 @@ t_CKBOOL type_engine_scan1_prog( Chuck_Env * env, a_Program prog,
             // scan the class definition
             ret = type_engine_scan1_class_def( env, prog->section->class_def );
             break;
-        
+
         default:
             EM_error2( prog->linepos,
                 "internal error: unrecognized program section in type checker pre-scan..." );
@@ -441,7 +441,7 @@ t_CKBOOL type_engine_scan1_stmt_list( Chuck_Env * env, a_Stmt_List list )
         // the current statement
         if( !type_engine_scan1_stmt( env, list->stmt ) )
             return FALSE;
-        
+
         // advance to the next statement
         list = list->next;
     }
@@ -506,7 +506,7 @@ t_CKBOOL type_engine_scan1_stmt( Chuck_Env * env, a_Stmt stmt )
             env->curr->value.pop();
             env->class_scope--;
             break;
-        
+
         case ae_stmt_exp:
             ret = type_engine_scan1_exp( env, stmt->stmt_exp );
             break;
@@ -544,7 +544,7 @@ t_CKBOOL type_engine_scan1_stmt( Chuck_Env * env, a_Stmt stmt )
             break;
 
         default:
-            EM_error2( stmt->linepos, 
+            EM_error2( stmt->linepos,
                 "internal compiler error (pre-scan) - no stmt type '%i'!", stmt->s_type );
             ret = FALSE;
             break;
@@ -565,7 +565,7 @@ t_CKBOOL type_engine_scan1_if( Chuck_Env * env, a_Stmt_If stmt )
     // check the conditional
     if( !type_engine_scan1_exp( env, stmt->cond ) )
         return FALSE;
-        
+
     // TODO: ensure that conditional has valid type
 
     // check if
@@ -592,7 +592,7 @@ t_CKBOOL type_engine_scan1_for( Chuck_Env * env, a_Stmt_For stmt )
     // check the initial
     if( !type_engine_scan1_stmt( env, stmt->c1 ) )
         return FALSE;
-    
+
     // check the conditional
     if( !type_engine_scan1_stmt( env, stmt->c2 ) )
         return FALSE;
@@ -622,7 +622,7 @@ t_CKBOOL type_engine_scan1_while( Chuck_Env * env, a_Stmt_While stmt )
     // check the conditional
     if( !type_engine_scan1_exp( env, stmt->cond ) )
         return FALSE;
-        
+
     // TODO: same as if - ensure the type in conditional is valid
 
     // check the body
@@ -644,7 +644,7 @@ t_CKBOOL type_engine_scan1_until( Chuck_Env * env, a_Stmt_Until stmt )
     // check the conditional
     if( !type_engine_scan1_exp( env, stmt->cond ) )
         return FALSE;
-        
+
     // TODO: same as if - ensure the type in conditional is valid
 
     // check the body
@@ -666,7 +666,7 @@ t_CKBOOL type_engine_scan1_loop( Chuck_Env * env, a_Stmt_Loop stmt )
     // check the conditional
     if( !type_engine_scan1_exp( env, stmt->cond ) )
         return FALSE;
-        
+
     // TODO: same as if - ensure the type in conditional is valid
 
     // check the body
@@ -755,7 +755,7 @@ t_CKBOOL type_engine_scan1_code_segment( Chuck_Env * env, a_Stmt_Code stmt,
     if( push ) env->curr->value.pop();  // env->context->nspc.value.pop();
     // class
     env->class_scope--;
-    
+
     return t;
 }
 
@@ -770,7 +770,7 @@ t_CKBOOL type_engine_scan1_exp( Chuck_Env * env, a_Exp exp )
 {
     a_Exp curr = exp;
     t_CKBOOL ret = TRUE;
-    
+
     // loop through parallel expressions
     while( curr )
     {
@@ -780,43 +780,43 @@ t_CKBOOL type_engine_scan1_exp( Chuck_Env * env, a_Exp exp )
         case ae_exp_binary:
             ret = type_engine_scan1_exp_binary( env, &curr->binary );
         break;
-    
+
         case ae_exp_unary:
             ret = type_engine_scan1_exp_unary( env, &curr->unary );
         break;
-    
+
         case ae_exp_cast:
             ret = type_engine_scan1_exp_cast( env, &curr->cast );
         break;
-    
+
         case ae_exp_postfix:
             ret = type_engine_scan1_exp_postfix( env, &curr->postfix );
         break;
-    
+
         case ae_exp_dur:
             ret = type_engine_scan1_exp_dur( env, &curr->dur );
         break;
-    
+
         case ae_exp_primary:
             ret = type_engine_scan1_exp_primary( env, &curr->primary );
         break;
-    
+
         case ae_exp_array:
             ret = type_engine_scan1_exp_array( env, &curr->array );
         break;
-    
+
         case ae_exp_func_call:
             ret = type_engine_scan1_exp_func_call( env, &curr->func_call );
         break;
-    
+
         case ae_exp_dot_member:
             ret = type_engine_scan1_exp_dot_member( env, &curr->dot_member );
         break;
-    
+
         case ae_exp_if:
             ret = type_engine_scan1_exp_if( env, &curr->exp_if );
         break;
-    
+
         case ae_exp_decl:
             ret = type_engine_scan1_exp_decl( env, &curr->decl );
         break;
@@ -854,7 +854,7 @@ t_CKBOOL type_engine_scan1_exp_binary( Chuck_Env * env, a_Exp_Binary binary )
     // type check the lhs and rhs
     t_CKBOOL left = type_engine_scan1_exp( env, cl );
     t_CKBOOL right = type_engine_scan1_exp( env, cr);
-    
+
     // if either fails, then return FALSE
     if( !left || !right )
         return FALSE;
@@ -868,7 +868,7 @@ t_CKBOOL type_engine_scan1_exp_binary( Chuck_Env * env, a_Exp_Binary binary )
 
         cr = cr->next;
     }
-        
+
     return TRUE;
 }
 
@@ -879,11 +879,11 @@ t_CKBOOL type_engine_scan1_exp_binary( Chuck_Env * env, a_Exp_Binary binary )
 // name: type_engine_scan1_op()
 // desc: ...
 //-----------------------------------------------------------------------------
-t_CKBOOL type_engine_scan1_op( Chuck_Env * env, ae_Operator op, a_Exp lhs, a_Exp rhs, 
+t_CKBOOL type_engine_scan1_op( Chuck_Env * env, ae_Operator op, a_Exp lhs, a_Exp rhs,
                               a_Exp_Binary binary )
 {
     // TODO: check for static here
-    
+
     return TRUE;
 }
 
@@ -1004,7 +1004,7 @@ t_CKBOOL type_engine_scan1_exp_dur( Chuck_Env * env, a_Exp_Dur dur )
     // type check the two components
     t_CKBOOL base = type_engine_scan1_exp( env, dur->base );
     t_CKBOOL unit = type_engine_scan1_exp( env, dur->unit );
-    
+
     // make sure both type check
     if( !base || !unit ) return FALSE;
 
@@ -1023,7 +1023,7 @@ t_CKBOOL type_engine_scan1_exp_postfix( Chuck_Env * env, a_Exp_Postfix postfix )
     // check the exp
     t_CKBOOL t = type_engine_scan1_exp( env, postfix->exp );
     if( !t ) return FALSE;
-    
+
     // syntax
     // TODO: figure out ++/--
     switch( postfix->op )
@@ -1038,19 +1038,19 @@ t_CKBOOL type_engine_scan1_exp_postfix( Chuck_Env * env, a_Exp_Postfix postfix )
                     op2str( postfix->op ) );
                 return FALSE;
             }
-            
+
             // TODO: mark somewhere we need to post increment
-            
+
             return TRUE;
         break;
-        
+
         default:
             // no match
             EM_error2( postfix->linepos,
                 "internal compiler error (pre-scan): unrecognized postfix '%i'", postfix->op );
             return FALSE;
     }
-    
+
     return TRUE;
 }
 
@@ -1070,7 +1070,7 @@ t_CKBOOL type_engine_scan1_exp_if( Chuck_Env * env, a_Exp_If exp_if )
 
     // make sure everything good
     if( !cond || !if_exp || !else_exp ) return FALSE;
-    
+
     return TRUE;
 }
 
@@ -1137,6 +1137,9 @@ t_CKBOOL type_engine_scan1_exp_decl( Chuck_Env * env, a_Exp_Decl decl )
             }
         }
 
+        // 1.4.2.0 (ge) added: var_decl->ck_type = t;
+        SAFE_REF_ASSIGN( var_decl->ck_type, t );
+
         // the next var decl
         list = list->next;
     }
@@ -1154,7 +1157,7 @@ t_CKBOOL type_engine_scan1_exp_decl( Chuck_Env * env, a_Exp_Decl decl )
 // name: type_engine_scan1_exp_func_call()
 // desc: ...
 //-----------------------------------------------------------------------------
-t_CKBOOL type_engine_scan1_exp_func_call( Chuck_Env * env, a_Exp exp_func, a_Exp args, 
+t_CKBOOL type_engine_scan1_exp_func_call( Chuck_Env * env, a_Exp exp_func, a_Exp args,
                                          t_CKFUNC & ck_func, int linepos )
 {
     // Chuck_Func * func = NULL;
@@ -1220,11 +1223,11 @@ t_CKBOOL type_engine_scan1_exp_array( Chuck_Env * env, a_Exp_Array array )
     // type check the base
     t_CKBOOL base = type_engine_scan1_exp( env, array->base );
     if( !base ) return FALSE;
-        
+
     // type check the index
     t_CKBOOL index = type_engine_scan1_exp( env, array->indices->exp_list );
     if( !index ) return FALSE;
-    
+
     // cycle through each exp
     // a_Exp e = array->indices->exp_list;
     // count the dimension
@@ -1268,18 +1271,18 @@ t_CKBOOL type_engine_scan1_class_def( Chuck_Env * env, a_Class_Def class_def )
             // do the statements
             ret = type_engine_scan1_stmt_list( env, body->section->stmt_list );
             break;
-        
+
         case ae_section_func:
             // do the function
             ret = type_engine_scan1_func_def( env, body->section->func_def );
             break;
-        
+
         case ae_section_class:
             // do the class
             ret = type_engine_scan1_class_def( env, body->section->class_def );
             break;
         }
-        
+
         // move to the next section
         body = body->next;
     }
@@ -1318,7 +1321,7 @@ t_CKBOOL type_engine_scan1_func_def( Chuck_Env * env, a_Func_Def f )
             S_name(f->name) );
         return FALSE;
     }
-    
+
     // look up the return type
     f->ret_type = type_engine_find_type( env, f->type_decl->xid );
     // no return type
@@ -1334,7 +1337,7 @@ t_CKBOOL type_engine_scan1_func_def( Chuck_Env * env, a_Func_Def f )
         // verify there are no errors from the parser...
         if( !verify_array( f->type_decl->array ) )
             return FALSE;
-        
+
         Chuck_Type * t = NULL;
         Chuck_Type * t2 = f->ret_type;
         // should be partial and empty []
@@ -1375,8 +1378,8 @@ t_CKBOOL type_engine_scan1_func_def( Chuck_Env * env, a_Func_Def f )
         {
             // TODO: try to resolve
             // EM_error2( arg_list->linepos, "in function '%s':", S_name(f->name) );
-            EM_error2( arg_list->linepos, 
-                "... in argument %i '%s' of function '%s(.)' ...", 
+            EM_error2( arg_list->linepos,
+                "... in argument %i '%s' of function '%s(.)' ...",
                 count, S_name(arg_list->var_decl->xid), S_name(f->name) );
             goto error;
         }
@@ -1436,7 +1439,7 @@ t_CKBOOL type_engine_scan2_prog( Chuck_Env * env, a_Program prog,
             // scan the statements
             ret = type_engine_scan2_stmt_list( env, prog->section->stmt_list );
             break;
-        
+
         case ae_section_func:
             // if classes only, then skip
             if( how_much == te_do_classes_only ) break;
@@ -1450,7 +1453,7 @@ t_CKBOOL type_engine_scan2_prog( Chuck_Env * env, a_Program prog,
             // scan the class definition
             ret = type_engine_scan2_class_def( env, prog->section->class_def );
             break;
-        
+
         default:
             EM_error2( prog->linepos,
                 "internal error: unrecognized program section in type checker pre-scan..." );
@@ -1482,7 +1485,7 @@ t_CKBOOL type_engine_scan2_stmt_list( Chuck_Env * env, a_Stmt_List list )
         // the current statement
         if( !type_engine_scan2_stmt( env, list->stmt ) )
             return FALSE;
-        
+
         // advance to the next statement
         list = list->next;
     }
@@ -1531,7 +1534,7 @@ t_CKBOOL type_engine_scan2_stmt( Chuck_Env * env, a_Stmt stmt )
             env->curr->value.pop();
             env->class_scope--;
             break;
-            
+
         case ae_stmt_until:
             env->class_scope++;
             env->curr->value.push();
@@ -1547,7 +1550,7 @@ t_CKBOOL type_engine_scan2_stmt( Chuck_Env * env, a_Stmt stmt )
             env->curr->value.pop();
             env->class_scope--;
             break;
-        
+
         case ae_stmt_exp:
             ret = type_engine_scan2_exp( env, stmt->stmt_exp );
             break;
@@ -1585,7 +1588,7 @@ t_CKBOOL type_engine_scan2_stmt( Chuck_Env * env, a_Stmt stmt )
             break;
 
         default:
-            EM_error2( stmt->linepos, 
+            EM_error2( stmt->linepos,
                 "internal compiler error (pre-scan) - no stmt type '%i'!", stmt->s_type );
             ret = FALSE;
             break;
@@ -1606,7 +1609,7 @@ t_CKBOOL type_engine_scan2_if( Chuck_Env * env, a_Stmt_If stmt )
     // check the conditional
     if( !type_engine_scan2_exp( env, stmt->cond ) )
         return FALSE;
-        
+
     // TODO: ensure that conditional has valid type
 
     // check if
@@ -1633,7 +1636,7 @@ t_CKBOOL type_engine_scan2_for( Chuck_Env * env, a_Stmt_For stmt )
     // check the initial
     if( !type_engine_scan2_stmt( env, stmt->c1 ) )
         return FALSE;
-    
+
     // check the conditional
     if( !type_engine_scan2_stmt( env, stmt->c2 ) )
         return FALSE;
@@ -1663,7 +1666,7 @@ t_CKBOOL type_engine_scan2_while( Chuck_Env * env, a_Stmt_While stmt )
     // check the conditional
     if( !type_engine_scan2_exp( env, stmt->cond ) )
         return FALSE;
-        
+
     // TODO: same as if - ensure the type in conditional is valid
 
     // check the body
@@ -1685,7 +1688,7 @@ t_CKBOOL type_engine_scan2_until( Chuck_Env * env, a_Stmt_Until stmt )
     // check the conditional
     if( !type_engine_scan2_exp( env, stmt->cond ) )
         return FALSE;
-        
+
     // TODO: same as if - ensure the type in conditional is valid
 
     // check the body
@@ -1707,7 +1710,7 @@ t_CKBOOL type_engine_scan2_loop( Chuck_Env * env, a_Stmt_Loop stmt )
     // check the conditional
     if( !type_engine_scan2_exp( env, stmt->cond ) )
         return FALSE;
-        
+
     // TODO: same as if - ensure the type in conditional is valid
 
     // check the body
@@ -1796,7 +1799,7 @@ t_CKBOOL type_engine_scan2_code_segment( Chuck_Env * env, a_Stmt_Code stmt,
     if( push ) env->curr->value.pop();  // env->context->nspc.value.pop();
     // class
     env->class_scope--;
-    
+
     return t;
 }
 
@@ -1811,7 +1814,7 @@ t_CKBOOL type_engine_scan2_exp( Chuck_Env * env, a_Exp exp )
 {
     a_Exp curr = exp;
     t_CKBOOL ret = TRUE;
-    
+
     // loop through parallel expressions
     while( curr )
     {
@@ -1821,43 +1824,43 @@ t_CKBOOL type_engine_scan2_exp( Chuck_Env * env, a_Exp exp )
         case ae_exp_binary:
             ret = type_engine_scan2_exp_binary( env, &curr->binary );
         break;
-    
+
         case ae_exp_unary:
             ret = type_engine_scan2_exp_unary( env, &curr->unary );
         break;
-    
+
         case ae_exp_cast:
             ret = type_engine_scan2_exp_cast( env, &curr->cast );
         break;
-    
+
         case ae_exp_postfix:
             ret = type_engine_scan2_exp_postfix( env, &curr->postfix );
         break;
-    
+
         case ae_exp_dur:
             ret = type_engine_scan2_exp_dur( env, &curr->dur );
         break;
-    
+
         case ae_exp_primary:
             ret = type_engine_scan2_exp_primary( env, &curr->primary );
         break;
-    
+
         case ae_exp_array:
             ret = type_engine_scan2_exp_array( env, &curr->array );
         break;
-    
+
         case ae_exp_func_call:
             ret = type_engine_scan2_exp_func_call( env, &curr->func_call );
         break;
-    
+
         case ae_exp_dot_member:
             ret = type_engine_scan2_exp_dot_member( env, &curr->dot_member );
         break;
-    
+
         case ae_exp_if:
             ret = type_engine_scan2_exp_if( env, &curr->exp_if );
         break;
-    
+
         case ae_exp_decl:
             ret = type_engine_scan2_exp_decl( env, &curr->decl );
         break;
@@ -1895,7 +1898,7 @@ t_CKBOOL type_engine_scan2_exp_binary( Chuck_Env * env, a_Exp_Binary binary )
     // type check the lhs and rhs
     t_CKBOOL left = type_engine_scan2_exp( env, cl );
     t_CKBOOL right = type_engine_scan2_exp( env, cr);
-    
+
     // if either fails, then return FALSE
     if( !left || !right )
         return FALSE;
@@ -1909,7 +1912,7 @@ t_CKBOOL type_engine_scan2_exp_binary( Chuck_Env * env, a_Exp_Binary binary )
 
         cr = cr->next;
     }
-        
+
     return TRUE;
 }
 
@@ -1920,11 +1923,11 @@ t_CKBOOL type_engine_scan2_exp_binary( Chuck_Env * env, a_Exp_Binary binary )
 // name: type_engine_scan2_op()
 // desc: ...
 //-----------------------------------------------------------------------------
-t_CKBOOL type_engine_scan2_op( Chuck_Env * env, ae_Operator op, a_Exp lhs, a_Exp rhs, 
+t_CKBOOL type_engine_scan2_op( Chuck_Env * env, ae_Operator op, a_Exp lhs, a_Exp rhs,
                                  a_Exp_Binary binary )
 {
     // TODO: check for static here
-    
+
     return TRUE;
 }
 
@@ -2045,7 +2048,7 @@ t_CKBOOL type_engine_scan2_exp_dur( Chuck_Env * env, a_Exp_Dur dur )
     // type check the two components
     t_CKBOOL base = type_engine_scan2_exp( env, dur->base );
     t_CKBOOL unit = type_engine_scan2_exp( env, dur->unit );
-    
+
     // make sure both type check
     if( !base || !unit ) return FALSE;
 
@@ -2064,7 +2067,7 @@ t_CKBOOL type_engine_scan2_exp_postfix( Chuck_Env * env, a_Exp_Postfix postfix )
     // check the exp
     t_CKBOOL t = type_engine_scan2_exp( env, postfix->exp );
     if( !t ) return FALSE;
-    
+
     // syntax
     // TODO: figure out ++/--
     switch( postfix->op )
@@ -2079,19 +2082,19 @@ t_CKBOOL type_engine_scan2_exp_postfix( Chuck_Env * env, a_Exp_Postfix postfix )
                     op2str( postfix->op ) );
                 return FALSE;
             }
-            
+
             // TODO: mark somewhere we need to post increment
-            
+
             return TRUE;
         break;
-        
+
         default:
             // no match
             EM_error2( postfix->linepos,
                 "internal compiler error (pre-scan): unrecognized postfix '%i'", postfix->op );
             return FALSE;
     }
-    
+
     return TRUE;
 }
 
@@ -2111,7 +2114,7 @@ t_CKBOOL type_engine_scan2_exp_if( Chuck_Env * env, a_Exp_If exp_if )
 
     // make sure everything good
     if( !cond || !if_exp || !else_exp ) return FALSE;
-    
+
     return TRUE;
 }
 
@@ -2141,6 +2144,7 @@ t_CKBOOL type_engine_scan2_exp_decl( Chuck_Env * env, a_Exp_Decl decl )
     Chuck_Type * type = NULL;
     Chuck_Value * value = NULL;
     t_CKBOOL do_alloc = TRUE;
+    t_CKBOOL is_first_in_list = TRUE;
 
     // retrieve the type
     type = decl->ck_type;
@@ -2185,13 +2189,21 @@ t_CKBOOL type_engine_scan2_exp_decl( Chuck_Env * env, a_Exp_Decl decl )
     // loop through the variables
     while( list != NULL )
     {
+        // 1.4.2.0 (ge) | reset the type variable to the lead type in the decl
+        // e.g., for cases like int x[2], y;
+        // ...this is so y would not be associated with x's array type
+        type = decl->ck_type;
+
         // get the decl
         var_decl = list->var_decl;
+        // 1.4.2.0 (ge) | by default, copy the decl type reference bit
+        // this could be overwritten later as appropriate, e.g., by array vars
+        var_decl->ref = decl->type->ref;
 
         // check if reserved
         if( type_engine_check_reserved( env, var_decl->xid, var_decl->linepos ) )
         {
-            EM_error2( var_decl->linepos, 
+            EM_error2( var_decl->linepos,
                 "...in variable declaration", S_name(var_decl->xid) );
             return FALSE;
         }
@@ -2212,7 +2224,10 @@ t_CKBOOL type_engine_scan2_exp_decl( Chuck_Env * env, a_Exp_Decl decl )
             if( !verify_array( var_decl->array ) )
                 return FALSE;
 
-            Chuck_Type * t2 = type;
+            // 1.4.2.0 (ge) was: decl->type->ref;
+            var_decl->ref = ( var_decl->array->exp_list == NULL );
+            // the declaration type | 1.4.2.0 (ge) fixed for multiple decl (e.g., int x[1], y[2];)
+            Chuck_Type * t2 = decl->ck_type; // was: type, which won't work if more than one var declared
             // may be partial and empty []
             if( var_decl->array->exp_list )
             {
@@ -2233,12 +2248,22 @@ t_CKBOOL type_engine_scan2_exp_decl( Chuck_Env * env, a_Exp_Decl decl )
                 env->curr  // the owner namespace
             );
 
-            // set ref
-            if( !var_decl->array->exp_list )
-                decl->type->ref = TRUE;
+            // 1.4.2.0 (ge) | assign new array type to current var decl
+            // for handling the following kind of multi-var declarations
+            //   int x[1], y[2];
+            //   int x, y[1];
+            // set reference : var_decl->ck_type = type;
+            SAFE_REF_ASSIGN( var_decl->ck_type, type );
 
-            // set reference : decl->ck_type = type;
-            SAFE_REF_ASSIGN( decl->ck_type, type );
+            // 1.4.2.0 (ge) | if one and only one variable, then update decl->ck_type
+            // otherwise, the variables could have different array depths, and therefore different types
+            // also note: cannot => to a multi-variable declaration (e.g., 5 => int x, y;)
+            // this is to support array initialization (e.g., [ [1,2], [3,4] ] @=> int x[][];)
+            if( is_first_in_list && list->next == NULL )
+            {
+                // set reference : var_decl->ck_type = type;
+                SAFE_REF_ASSIGN( decl->ck_type, type );
+            }
         }
 
         // enter into value binding
@@ -2248,14 +2273,14 @@ t_CKBOOL type_engine_scan2_exp_decl( Chuck_Env * env, a_Exp_Decl decl )
         // remember the owner
         value->owner = env->curr;
         value->owner_class = env->func ? NULL : env->class_def;
-        value->is_member = ( env->class_def != NULL && 
-                             env->class_scope == 0 && 
+        value->is_member = ( env->class_def != NULL &&
+                             env->class_scope == 0 &&
                              env->func == NULL && !decl->is_static );
         value->is_context_global = ( env->class_def == NULL && env->func == NULL );
         value->addr = var_decl->addr;
         // flag it until the decl is checked
         value->is_decl_checked = FALSE;
-        
+
         // flag as global
         value->is_global = decl->is_global;
 
@@ -2264,6 +2289,8 @@ t_CKBOOL type_engine_scan2_exp_decl( Chuck_Env * env, a_Exp_Decl decl )
 
         // the next var decl
         list = list->next;
+        // 1.4.2.0 (ge) | added
+        is_first_in_list = FALSE;
     }
 
     return TRUE;
@@ -2276,7 +2303,7 @@ t_CKBOOL type_engine_scan2_exp_decl( Chuck_Env * env, a_Exp_Decl decl )
 // name: type_engine_scan2_exp_func_call()
 // desc: ...
 //-----------------------------------------------------------------------------
-t_CKBOOL type_engine_scan2_exp_func_call( Chuck_Env * env, a_Exp exp_func, a_Exp args, 
+t_CKBOOL type_engine_scan2_exp_func_call( Chuck_Env * env, a_Exp exp_func, a_Exp args,
                                             t_CKFUNC & ck_func, int linepos )
 {
     // Chuck_Func * func = NULL;
@@ -2342,11 +2369,11 @@ t_CKBOOL type_engine_scan2_exp_array( Chuck_Env * env, a_Exp_Array array )
     // type check the base
     t_CKBOOL base = type_engine_scan2_exp( env, array->base );
     if( !base ) return FALSE;
-        
+
     // type check the index
     t_CKBOOL index = type_engine_scan2_exp( env, array->indices->exp_list );
     if( !index ) return FALSE;
-    
+
     // cycle through each exp
     // a_Exp e = array->indices->exp_list;
     // count the dimension
@@ -2380,7 +2407,7 @@ t_CKBOOL type_engine_scan2_class_def( Chuck_Env * env, a_Class_Def class_def )
     env->class_stack.push_back( env->class_def );
     env->class_def = the_class;
     // reset the nest list
-    env->class_scope = 0;    
+    env->class_scope = 0;
 
     // type check the body
     while( body && ret )
@@ -2403,7 +2430,7 @@ t_CKBOOL type_engine_scan2_class_def( Chuck_Env * env, a_Class_Def class_def )
             ret = type_engine_scan2_class_def( env, body->section->class_def );
             break;
         }
-        
+
         // move to the next section
         body = body->next;
     }
@@ -2462,11 +2489,11 @@ t_CKBOOL type_engine_scan2_func_def( Chuck_Env * env, a_Func_Def f )
         // if value
         if( !isa( overload->type, env->t_function ) )
         {
-            EM_error2( f->linepos, 
+            EM_error2( f->linepos,
                 "function name '%s' is already used by another value", S_name(f->name) );
             return FALSE;
         }
-        else 
+        else
         {
             // overload
             if( !overload->func_ref )
@@ -2504,7 +2531,7 @@ t_CKBOOL type_engine_scan2_func_def( Chuck_Env * env, a_Func_Def f )
     // reference the function definition
     func->def = f;
     // note whether the function is marked as member
-    func->is_member = (f->static_decl != ae_key_static) && 
+    func->is_member = (f->static_decl != ae_key_static) &&
                       (env->class_def != NULL);
     // note whether the function is marked as static (in class)
     func->is_static = (f->static_decl == ae_key_static) &&
@@ -2635,7 +2662,7 @@ t_CKBOOL type_engine_scan2_func_def( Chuck_Env * env, a_Func_Def f )
             // verify there are no errors from the parser...
             if( !verify_array( arg_list->var_decl->array ) )
                 return FALSE;
-            
+
             Chuck_Type * t = arg_list->type;
             Chuck_Type * t2 = t;
             // should be partial and empty []
@@ -2661,9 +2688,9 @@ t_CKBOOL type_engine_scan2_func_def( Chuck_Env * env, a_Func_Def f )
             // set type : arg_list->type = t;
             SAFE_REF_ASSIGN( arg_list->type, t );
         }
-        
+
         // make new value
-        v = env->context->new_Chuck_Value( 
+        v = env->context->new_Chuck_Value(
             arg_list->type, S_name(arg_list->var_decl->xid) );
         // remember the owner
         v->owner = env->curr;
@@ -2727,7 +2754,7 @@ t_CKBOOL type_engine_scan2_func_def( Chuck_Env * env, a_Func_Def f )
     }
 
     // pop the value stack
-    env->curr->value.pop();    
+    env->curr->value.pop();
     // clear the env's function definition
     env->func = NULL;
 
