@@ -53,12 +53,6 @@ static t_CKCOMPLEX g_i = { 0.0, 1.0 };
 static t_CKFLOAT fzero() { return 0.0; }
 
 
-#ifdef __WINDOWS_DS__
-static long random() { return rand(); }
-static void srandom( unsigned s ) { srand( s ); }
-#endif // __WINDOWS_DS__
-
-
 // query
 DLL_QUERY libmath_query( Chuck_DL_Query * QUERY )
 {
@@ -78,12 +72,12 @@ DLL_QUERY libmath_query( Chuck_DL_Query * QUERY )
     QUERY->begin_class( QUERY, "Math", "Object" );
     // add documentatiopn
     QUERY->doc_class( QUERY, "math class library." );
-    
+
     // add abs
     QUERY->add_sfun( QUERY, abs_impl, "int", "abs" );
     QUERY->add_arg( QUERY, "int", "value" );
     QUERY->doc_func( QUERY, "absolute value (integer)." );
-    
+
     // add fabs
     QUERY->add_sfun( QUERY, fabs_impl, "float", "fabs" );
     QUERY->add_arg( QUERY, "float", "value" );
@@ -93,12 +87,12 @@ DLL_QUERY libmath_query( Chuck_DL_Query * QUERY )
     QUERY->add_sfun( QUERY, sgn_impl, "float", "sgn" );
     QUERY->add_arg( QUERY, "float", "value" );
     QUERY->doc_func( QUERY, "get sign of value as -1 (negative), 0, or 1 (positive)." );
-    
+
     // sin
     QUERY->add_sfun( QUERY, sin_impl, "float", "sin" );
     QUERY->add_arg( QUERY, "float", "x" );
     QUERY->doc_func( QUERY, "compute sine of x (measured in radians)." );
-    
+
     // cos
     QUERY->add_sfun( QUERY, cos_impl, "float", "cos" );
     QUERY->add_arg( QUERY, "float", "x" );
@@ -259,18 +253,18 @@ DLL_QUERY libmath_query( Chuck_DL_Query * QUERY )
 
     // floatMax
     // QUERY->add_sfun( QUERY, floatMax_impl, "float", "floatMax" );
-    
+
     // intMax
     // QUERY->add_sfun( QUERY, intMax_impl, "int", "intMax" );
-    
+
     // rand
     // QUERY->add_sfun( QUERY, rand_impl, "int", "rand" ); //! return int between 0 and RAND_MAX
-    
+
     // rand2
     // QUERY->add_sfun( QUERY, rand2_impl, "int", "rand2" ); //! integer between [min,max]
-    // QUERY->add_arg( QUERY, "int", "min" ); 
-    // QUERY->add_arg( QUERY, "int", "max" ); 
-    
+    // QUERY->add_arg( QUERY, "int", "min" );
+    // QUERY->add_arg( QUERY, "int", "max" );
+
     // randf
     // QUERY->add_sfun( QUERY, randf_impl, "float", "randf" ); //! rand between -1.0,1.0
 
@@ -291,7 +285,7 @@ DLL_QUERY libmath_query( Chuck_DL_Query * QUERY )
     QUERY->doc_func( QUERY, "convert frequency (Hz) to MIDI note number." );
 
     // add powtodb
-    QUERY->add_sfun( QUERY, powtodb_impl, "float", "powtodb" ); //! linear power to decibel 
+    QUERY->add_sfun( QUERY, powtodb_impl, "float", "powtodb" ); //! linear power to decibel
     QUERY->add_arg( QUERY, "float", "value" );
     QUERY->doc_func( QUERY, "convert signal power ratio to decibels (dB)." );
 
@@ -309,27 +303,27 @@ DLL_QUERY libmath_query( Chuck_DL_Query * QUERY )
     QUERY->add_sfun( QUERY, dbtorms_impl, "float", "dbtorms" ); //! decibel to rms
     QUERY->add_arg( QUERY, "float", "value" );
     QUERY->doc_func( QUERY, "convert decibles (dB) to linear amplitude." );
-    
+
     // add re
     QUERY->add_sfun( QUERY, re_impl, "float", "re" ); //! real component of complex
     QUERY->add_arg( QUERY, "complex", "v" );
     QUERY->doc_func( QUERY, "return the real component of complex value v." );
-    
+
     // add im
     QUERY->add_sfun( QUERY, im_impl, "float", "im" ); //! imaginary component of complex
     QUERY->add_arg( QUERY, "complex", "v" );
     QUERY->doc_func( QUERY, "return the real component of complex value v." );
-    
+
     // add mag
     QUERY->add_sfun( QUERY, modulus_impl, "float", "mag" ); //! mag
     QUERY->add_arg( QUERY, "polar", "v" );
     QUERY->doc_func( QUERY, "return the magnitude component of polar value v." );
-    
+
     // add phase
     QUERY->add_sfun( QUERY, phase_impl, "float", "phase" ); //! phase
     QUERY->add_arg( QUERY, "polar", "v" );
     QUERY->doc_func( QUERY, "return the phase component of polar value v." );
-    
+
     // add rtop
     QUERY->add_sfun( QUERY, rtop_impl, "int", "rtop" ); // rect to polar
     QUERY->add_arg( QUERY, "complex[]", "from" );
@@ -345,30 +339,31 @@ DLL_QUERY libmath_query( Chuck_DL_Query * QUERY )
     // add random (1.3.1.0)
     QUERY->add_sfun( QUERY, random_impl, "int", "random"); //! return int between 0 and CK_RANDOM_MAX
     QUERY->doc_func( QUERY, "get successive pseudo-random integer numbers in the range [0, (2^31)-1]." );
-    
+
     // add random2 (1.3.1.0)
     QUERY->add_sfun( QUERY, random2_impl, "int", "random2" ); //! integer between [min,max]
-    QUERY->add_arg( QUERY, "int", "min" ); 
-    QUERY->add_arg( QUERY, "int", "max" ); 
+    QUERY->add_arg( QUERY, "int", "min" );
+    QUERY->add_arg( QUERY, "int", "max" );
     QUERY->doc_func( QUERY, "get successive pseudo-random numbers in the range [min, max]." );
-    
+
     // add randomf (1.3.1.0) -- NOTE different in return semantics
     QUERY->add_sfun( QUERY, randomf_impl, "float", "randomf" ); //! random between 0 and 1.0
     QUERY->doc_func( QUERY, "get successive pseudo-random floating-point numbers in the range [0,1]." );
-    
+
     // add random2f (1.3.1.0)
     QUERY->add_sfun( QUERY, random2f_impl, "float", "random2f" ); //! random between min and max
     QUERY->add_arg( QUERY, "float", "min" );
     QUERY->add_arg( QUERY, "float", "max" );
     QUERY->doc_func( QUERY, "get successive pseudo-random floating-point numbers in the range [min, max]." );
-    
+
     // add srandom (1.3.1.0)
     QUERY->add_sfun( QUERY, srandom_impl, "void", "srandom" );
     QUERY->add_arg( QUERY, "int", "seed" );
     QUERY->doc_func( QUERY, "seed the random nubmer generator." );
-    
+
     // go ahead and seed (the code can seed again for repeatability; 1.3.1.0)
-    srandom( time( NULL ) );
+    // updated to use ck_srandom() wrapper | 1.4.2.0 (ge)
+    ck_srandom( (unsigned)time( NULL ) );
 
     // add gauss (ge: added 1.3.5.3)
     QUERY->add_sfun( QUERY, gauss_impl, "float", "gauss" ); //! Gaussian function
@@ -578,12 +573,16 @@ CK_DLL_SFUN( ceil_impl )
 // round
 CK_DLL_SFUN( round_impl )
 {
+    // for older windows version (and miniAudicle windows build)
+    // enable this in the build __CK_MATH_DEFINE_ROUND_TRUNC__
     RETURN->v_float = round( GET_CK_FLOAT(ARGS) );
 }
 
 // trunc
 CK_DLL_SFUN( trunc_impl )
 {
+    // for older windows version (and miniAudicle windows build)
+    // enable this in the build __CK_MATH_DEFINE_ROUND_TRUNC__
     RETURN->v_float = trunc( GET_CK_FLOAT(ARGS) );
 }
 
@@ -756,12 +755,12 @@ CK_DLL_SFUN( rtop_impl )
         EM_log( CK_LOG_WARNING, "Math.rtop( ... ) was given one or more NULL arrays..." );
         return;
     }
-    
+
     // find how much to copy
     t_CKUINT count = ck_min( from->size(), to->size() );
     t_CKCOMPLEX c;
     t_CKCOMPLEX p;
-    
+
     // convert
     for( t_CKUINT i = 0; i < count; i++ )
     {
@@ -771,11 +770,11 @@ CK_DLL_SFUN( rtop_impl )
         p.im = ::atan2( c.im, c.re );
         to->set( i, p );
     }
-    
+
     // zero out the rest
     // if( count < to->size() ) to->zero( count, to->size() );
     if( count < to->size() ) to->set_size( count );
-    
+
     // return number of elements done
     RETURN->v_int = count;
 }
@@ -795,12 +794,12 @@ CK_DLL_SFUN( ptor_impl )
         EM_log( CK_LOG_WARNING, "Math.ptor( ... ) was given one or more NULL arrays..." );
         return;
     }
-    
+
     // find how much to copy
     t_CKUINT count = ck_min( from->size(), to->size() );
     t_CKCOMPLEX c;
     t_CKPOLAR p;
-    
+
     // convert
     for( t_CKUINT i = 0; i < count; i++ )
     {
@@ -810,11 +809,11 @@ CK_DLL_SFUN( ptor_impl )
         c.im = p.modulus * ::sin( p.phase );
         to->set( i, c );
     }
-    
+
     // zero out the rest
     // if( count < to->capacity() ) to->zero( count, to->size() );
     if( count < to->size() ) to->set_size( count );
-    
+
     // return number of elements done
     RETURN->v_int = count;
 }
@@ -823,14 +822,16 @@ CK_DLL_SFUN( ptor_impl )
 // random (added 1.3.1.0)
 CK_DLL_SFUN( random_impl )
 {
-    RETURN->v_int = ::random();
+    // 1.4.2.0 (ge) | updated to use ck_random() wrapper
+    RETURN->v_int = ck_random();
 }
 
 
 // randomf (added 1.3.1.0)
 CK_DLL_SFUN( randomf_impl )
 {
-    RETURN->v_float = ( ::random() / (t_CKFLOAT)CK_RANDOM_MAX );
+    // 1.4.2.0 (ge) | updated to use ck_random() wrapper
+    RETURN->v_float = ( ck_random() / (t_CKFLOAT)CK_RANDOM_MAX );
 }
 
 
@@ -838,7 +839,8 @@ CK_DLL_SFUN( randomf_impl )
 CK_DLL_SFUN( random2f_impl )
 {
     t_CKFLOAT min = GET_CK_FLOAT(ARGS), max = *((t_CKFLOAT *)ARGS + 1);
-    t_CKFLOAT normRand = ((t_CKFLOAT)::random()*1.0/(t_CKFLOAT)CK_RANDOM_MAX);
+    // 1.4.2.0 (ge) | updated to use ck_random() wrapper
+    t_CKFLOAT normRand = ck_random() / (t_CKFLOAT)CK_RANDOM_MAX;
     //CK_FPRINTF_STDERR( "[chuck random2f]: %G --> %G, %G\n", normRand, min, max );
     RETURN->v_float = min + (max-min)* normRand;
 }
@@ -849,23 +851,25 @@ CK_DLL_SFUN( random2_impl ) // inclusive.
 {
     // 1.3.1.0: converted int to t_CKINT for 64-bit compatibility
     t_CKINT min = *(t_CKINT *)ARGS, max = *((t_CKINT *)ARGS + 1);
-    t_CKINT range = max - min; 
+    t_CKINT range = max - min;
     if( range == 0 )
     {
         RETURN->v_int = min;
     }
-    //else if( range < RAND_MAX / 2 ) { 
+    //else if( range < RAND_MAX / 2 ) {
     //  RETURN->v_int = ( range > 0 ) ? min + irandom_exclusive(1 + range) : max + irandom_exclusive ( -range + 1 ) ;
     //}
     else
     {
         if( range > 0 )
-        { 
-            RETURN->v_int = min + (t_CKINT)( (1.0 + range) * ( ::random()/(CK_RANDOM_MAX+1.0) ) );
+        {
+            // 1.4.2.0 (ge) | updated to use ck_random() wrapper
+            RETURN->v_int = min + (t_CKINT)( (1.0 + range) * ( ck_random()/(CK_RANDOM_MAX+1.0) ) );
         }
         else
-        { 
-            RETURN->v_int = min - (t_CKINT)( (-range + 1.0) * ( ::random()/(CK_RANDOM_MAX+1.0) ) );
+        {
+            // 1.4.2.0 (ge) | updated to use ck_random() wrapper
+            RETURN->v_int = min - (t_CKINT)( (-range + 1.0) * ( ck_random()/(CK_RANDOM_MAX+1.0) ) );
         }
     }
 }
@@ -875,7 +879,8 @@ CK_DLL_SFUN( random2_impl ) // inclusive.
 CK_DLL_SFUN( srandom_impl )
 {
     t_CKINT seed = GET_CK_INT(ARGS);
-    ::srandom( seed );
+    // 1.4.2.0 (ge) | updated to use ck_srandom() wrapper
+    ck_srandom( (unsigned)seed );
 }
 
 
